character.coercion.culprits This function identifies which character values in a vector are preventing it from being converted to a numeric vector.
character.coercion.culprits(x, threshold.for.numeric = 0.5, ...)A character vector of values that are preventing x from being converted to numeric. Returns NA if the proportion of non-numeric values exceeds the threshold.
A character vector of values that should be a numeric vector but was coerced to a character due to a small number of non-numeric entries.
A value between 0 and 1 specifying the maximum proportion of x that does not "look" numeric. If threshold.for.numeric = 0.1, then no more than 10 percentage of the values in x can be values that do not "look" numeric.
Additional arguments.