Learn R Programming

DTwrappers2 (version 0.0.3)

lower.quartile: lower.quartile

Description

value that cuts off the first 25

Usage

lower.quartile(x, na.rm = TRUE, ...)

Value

Returns a numeric value representing the lower quartile (25th percentile) of the given vector 'x'. The lower quartile is the value below which 25

If 'na.rm' is TRUE, any missing values (NA) are removed before the calculation. The function utilizes the 'quantile' function internally to compute this statistic, and any additional arguments provided (...) are passed along to this underlying function.

Arguments

x

a vector

na.rm

a logical value specifying whether missing values should be removed from the calculations specified by the.functions.

...

additional arguments to be passed