Learn R Programming

DTwrappers2 (version 0.0.3)

round.numerics: round.numerics

Description

This function rounds numeric or complex values to the specified number of digits. If the input is not numeric or complex, the values are returned untouched.

Usage

# S3 method for numerics
round(x, digits = 0, ...)

Value

If x is numeric or complex, the values will be rounded to the specified number of digits. Otherwise, the values of x will be returned untouched.

Arguments

x

A vector.

digits

The number of digits to round to. Defaults to 0.

...

Additional arguments.