Learn R Programming

DTwrappers2 (version 0.0.3)

round_exactly_one_value: round_exactly_one_value This internal function rounds exactly one value to the specified number of digits.

Description

round_exactly_one_value This internal function rounds exactly one value to the specified number of digits.

Usage

round_exactly_one_value(x, digits)

Value

A character string representing the rounded value.

Arguments

x

A character vector where the first element is the integer part and the second element is the decimal part.

digits

The number of digits to round to.