This function rounds numeric or complex values to the specified number of digits. If the input is not numeric or complex, the values are returned untouched.
# S3 method for numerics
round(x, digits = 0, ...)If x is numeric or complex, the values will be rounded to the specified number of digits. Otherwise, the values of x will be returned untouched.
A vector.
The number of digits to round to. Defaults to 0.
Additional arguments.