round_exactly_one_value This internal function rounds exactly one value to the specified number of digits.
round_exactly_one_value(x, digits)A character string representing the rounded value.
A character vector where the first element is the integer part and the second element is the decimal part.
The number of digits to round to.